@@ -19,14 +19,23 @@ rSD.default <- function (sim, obs, na.rm=TRUE, ...){
      
      rSD <- sd(sim, na.rm= na.rm) / sd(obs, na.rm= na.rm) 
      
-     } else stop("'sd(obs)=0', it is not possible to compute 'rSD'")  
+     } else {
+        rSD <- NA
+        warning("'sd(obs)=0', it is not possible to compute 'rSD'")  
+       } # ELSE end
      
      return(rSD)
      
   } # 'rSD.default' end
   
   
-rSD.matrix <- function (sim, obs, na.rm=TRUE, ...){ 
+rSD.matrix <- function (sim, obs, na.rm=TRUE, ...){
+
+  # Checking that 'sim' and 'obs' have the same dimensions
+  if ( all.equal(dim(sim), dim(obs)) != TRUE )
+    stop( paste("Invalid argument: dim(sim) != dim(obs) ( [", 
+          paste(dim(sim), collapse=" "), "] != [", 
+          paste(dim(obs), collapse=" "), "] )", sep="") ) 
  
   rSD <- rep(NA, ncol(obs))       
           
